cumulusci.tasks.github.tests package
====================================

Submodules
----------

cumulusci.tasks.github.tests.test\_commit module
------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_commit
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_merge module
-----------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_merge
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_pull\_request module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_pull_request
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_release module
-------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_release
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_release\_report module
---------------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_release_report
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_tag module
---------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_tag
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.test\_util module
----------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.test_util
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.github.tests.util\_github\_api module
-----------------------------------------------------

.. automodule:: cumulusci.tasks.github.tests.util_github_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.github.tests
    :members:
    :undoc-members:
    :show-inheritance:
